==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/apcas/v20201127/models/CallDetails.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.apcas.v20201127.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CallDetails extends AbstractModel{

    /**
    * 符合条件的总条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 调用明细数组
    */
    @SerializedName("CallDetailSet")
    @Expose
    private CallDetailItem [] CallDetailSet;

    /**
     * Get 符合条件的总条数 
     * @return TotalCount 符合条件的总条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 符合条件的总条数
     * @param TotalCount 符合条件的总条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 调用明细数组 
     * @return CallDetailSet 调用明细数组
     */
    public CallDetailItem [] getCallDetailSet() {
        return this.CallDetailSet;
    }

    /**
     * Set 调用明细数组
     * @param CallDetailSet 调用明细数组
     */
    public void setCallDetailSet(CallDetailItem [] CallDetailSet) {
        this.CallDetailSet = CallDetailSet;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "CallDetailSet.", this.CallDetailSet);

    }
}

==> tencentcloud-sdk-java-3.1.693-sources.jar: com/tencentcloudapi/apcas/v20201127/models/CallDetails.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.apcas.v20201127.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CallDetails extends AbstractModel{

    /**
    * 符合条件的总条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 调用明细数组
    */
    @SerializedName("CallDetailSet")
    @Expose
    private CallDetailItem [] CallDetailSet;

    /**
     * Get 符合条件的总条数 
     * @return TotalCount 符合条件的总条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 符合条件的总条数
     * @param TotalCount 符合条件的总条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 调用明细数组 
     * @return CallDetailSet 调用明细数组
     */
    public CallDetailItem [] getCallDetailSet() {
        return this.CallDetailSet;
    }

    /**
     * Set 调用明细数组
     * @param CallDetailSet 调用明细数组
     */
    public void setCallDetailSet(CallDetailItem [] CallDetailSet) {
        this.CallDetailSet = CallDetailSet;
    }

    public CallDetails() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CallDetails(CallDetails source) {
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.CallDetailSet != null) {
            this.CallDetailSet = new CallDetailItem[source.CallDetailSet.length];
            for (int i = 0; i < source.CallDetailSet.length; i++) {
                this.CallDetailSet[i] = new CallDetailItem(source.CallDetailSet[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "CallDetailSet.", this.CallDetailSet);

    }
}
